==> meld-tools-processor-0.1.7-sources.jar: ch/raffael/meldioc/processor/MemberNames.java <==
/*
 *  Copyright (c) 2021 Raffael Herzog
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a copy
 *  of this software and associated documentation files (the "Software"), to
 *  deal in the Software without restriction, including without limitation the
 *  rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 *  sell copies of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in
 *  all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 *  IN THE SOFTWARE.
 */

package ch.raffael.meldioc.processor;

import ch.raffael.meldioc.model.SrcElement;
import ch.raffael.meldioc.util.Strings;

final class MemberNames {

  private MemberNames() {
  }

  static String forMount(SrcElement<?, ?> element) {
    return prefixed("mount", element);
  }

  static String forMountClass(SrcElement<?, ?> element) {
    return prefixed("$Mount_", element);
  }

  private static String prefixed(String prefix, SrcElement<?, ?> element) {
    return prefix + Strings.capitalize(element.name());
  }

}

==> meld-tools-processor-0.2.0-sources.jar: ch/raffael/meldioc/processor/MemberNames.java <==
/*
 *  Copyright (c) 2022 Raffael Herzog
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a copy
 *  of this software and associated documentation files (the "Software"), to
 *  deal in the Software without restriction, including without limitation the
 *  rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 *  sell copies of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in
 *  all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 *  IN THE SOFTWARE.
 */

package ch.raffael.meldioc.processor;

import ch.raffael.meldioc.model.SrcElement;
import ch.raffael.meldioc.util.Strings;

final class MemberNames {

  private MemberNames() {
  }

  static String forMount(SrcElement<?, ?> element) {
    return prefixedSnake("mount", element);
  }

  static String forMountApi(SrcElement<?, ?> element) {
    return prefixedCamel("mount", element);
  }

  static String forMountClass(SrcElement<?, ?> element) {
    return prefixedSnake("$Mount", element);
  }

  private static String prefixedSnake(String prefix, SrcElement<?, ?> element) {
    return prefix + "_" + element.name();
  }

  private static String prefixedCamel(String prefix, SrcElement<?, ?> element) {
    return prefix + Strings.capitalize(element.name());
  }
}
